========
Orangery
========

Orangery is a Python library to support analysis of topographic cross-sections, particularly on stream channels. The intent is to enable the user to write simple scripts that operate on CSV data exported from a survey data collector.

Dependencies
============

Orangery 0.1 depends on:

* `Python 2.7`_
* NumPy_
* pandas_
* matplotlib_
* Shapely_

Installation
============

To install from the Python Package Index:

	$pip install orangery

To install from the source distribution execute the setup script in the orangery directory:

	$python setup.py install

Windows users may install using the .msi installer from the GitHub project `release page`_.

License
=======

BSD

Documentation
=============

In development.

.. _Python 2.7: http://www.python.org
.. _NumPy: http://www.numpy.org
.. _pandas: http://pandas.pydata.org
.. _matplotlib: http://matplotlib.org
.. _Shapely: https://github.com/Toblerity/Shapely

.. _release page: https://github.com/mrahnis/orangery/releases
